@@ -3,6 +3,7 @@ pub use direct_url::*;
 pub use lenient_requirement::*;
 pub use metadata::*;
 pub use parsed_url::*;
+pub use requirement::*;
 pub use scheme::*;
 pub use simple_json::*;
 
@@ -11,5 +12,6 @@ mod direct_url;
 mod lenient_requirement;
 mod metadata;
 mod parsed_url;
+mod requirement;
 mod scheme;
 mod simple_json;
