@@ -2,7 +2,6 @@ use std::fmt::Display;
 use std::path::{Path, PathBuf};
 
 use fs2::FileExt;
-use fs_err as fs;
 use tempfile::NamedTempFile;
 use tracing::{debug, error, trace, warn};
 
@@ -13,23 +12,6 @@ pub use crate::path::*;
 pub mod cachedir;
 mod path;
 
-/// Reads data from the path and requires that it be valid UTF-8.
-///
-/// If the file path is `-`, then contents are read from stdin instead.
-#[cfg(feature = "tokio")]
-pub async fn read_to_string(path: impl AsRef<Path>) -> std::io::Result<String> {
-    use std::io::Read;
-
-    let path = path.as_ref();
-    if path == Path::new("-") {
-        let mut buf = String::with_capacity(1024);
-        std::io::stdin().read_to_string(&mut buf)?;
-        Ok(buf)
-    } else {
-        fs_err::tokio::read_to_string(path).await
-    }
-}
-
 /// Reads data from the path and requires that it be valid UTF-8 or UTF-16.
 ///
 /// This uses BOM sniffing to determine if the data should be transcoded
@@ -150,25 +132,6 @@ pub fn write_atomic_sync(path: impl AsRef<Path>, data: impl AsRef<[u8]>) -> std:
     Ok(())
 }
 
-/// Remove the file or directory at `path`, if it exists.
-///
-/// Returns `true` if the file or directory was removed, and `false` if the path did not exist.
-pub fn force_remove_all(path: impl AsRef<Path>) -> Result<bool, std::io::Error> {
-    let path = path.as_ref();
-
-    let Some(metadata) = metadata_if_exists(path)? else {
-        return Ok(false);
-    };
-
-    if metadata.is_dir() {
-        fs::remove_dir_all(path)?;
-    } else {
-        fs::remove_file(path)?;
-    }
-
-    Ok(true)
-}
-
 /// Rename a file, retrying (on Windows) if it fails due to transient operating system errors.
 #[cfg(feature = "tokio")]
 pub async fn rename_with_retry(
@@ -327,14 +290,3 @@ impl Drop for LockedFile {
         }
     }
 }
-
-/// Given a path, return its metadata if the file exists, or `None` if it does not.
-///
-/// If the file exists but cannot be read, returns an error.
-pub fn metadata_if_exists(path: impl AsRef<Path>) -> std::io::Result<Option<std::fs::Metadata>> {
-    match fs::metadata(path) {
-        Ok(metadata) => Ok(Some(metadata)),
-        Err(err) if err.kind() == std::io::ErrorKind::NotFound => Ok(None),
-        Err(err) => Err(err),
-    }
-}
