@@ -12,6 +12,7 @@ use pypi_types::{Requirement, RequirementSource};
 use uv_configuration::{Constraints, Overrides};
 use uv_distribution::{DistributionDatabase, Reporter};
 use uv_git::GitUrl;
+use uv_normalize::GroupName;
 use uv_resolver::{InMemoryIndex, MetadataResponse};
 use uv_types::{BuildContext, HashStrategy, RequestedRequirements};
 
@@ -48,6 +49,8 @@ pub struct LookaheadResolver<'a, Context: BuildContext> {
     constraints: &'a Constraints,
     /// The overrides for the project.
     overrides: &'a Overrides,
+    /// The development dependency groups for the project.
+    dev: &'a [GroupName],
     /// The required hashes for the project.
     hasher: &'a HashStrategy,
     /// The in-memory index for resolving dependencies.
@@ -63,6 +66,7 @@ impl<'a, Context: BuildContext> LookaheadResolver<'a, Context> {
         requirements: &'a [Requirement],
         constraints: &'a Constraints,
         overrides: &'a Overrides,
+        dev: &'a [GroupName],
         hasher: &'a HashStrategy,
         index: &'a InMemoryIndex,
         database: DistributionDatabase<'a, Context>,
@@ -71,6 +75,7 @@ impl<'a, Context: BuildContext> LookaheadResolver<'a, Context> {
             requirements,
             constraints,
             overrides,
+            dev,
             hasher,
             index,
             database,
@@ -141,42 +146,15 @@ impl<'a, Context: BuildContext> LookaheadResolver<'a, Context> {
         requirement: Requirement,
     ) -> Result<Option<RequestedRequirements>, LookaheadError> {
         trace!("Performing lookahead for {requirement}");
+
         // Determine whether the requirement represents a local distribution and convert to a
         // buildable distribution.
-        let dist = match requirement.source {
-            RequirementSource::Registry { .. } => return Ok(None),
-            RequirementSource::Url {
-                subdirectory,
-                location,
-                url,
-            } => Dist::from_http_url(requirement.name, url, location, subdirectory)?,
-            RequirementSource::Git {
-                repository,
-                reference,
-                precise,
-                subdirectory,
-                url,
-            } => {
-                let mut git_url = GitUrl::new(repository, reference);
-                if let Some(precise) = precise {
-                    git_url = git_url.with_precise(precise);
-                }
-                Dist::Source(SourceDist::Git(GitSourceDist {
-                    name: requirement.name,
-                    git: Box::new(git_url),
-                    subdirectory,
-                    url,
-                }))
-            }
-            RequirementSource::Path {
-                path,
-                url,
-                editable,
-            } => Dist::from_file_url(requirement.name, url, &path, editable)?,
+        let Some(dist) = required_dist(&requirement)? else {
+            return Ok(None);
         };
 
         // Fetch the metadata for the distribution.
-        let requires_dist = {
+        let metadata = {
             let id = dist.version_id();
             if let Some(archive) =
                 self.index
@@ -192,7 +170,7 @@ impl<'a, Context: BuildContext> LookaheadResolver<'a, Context> {
                     })
             {
                 // If the metadata is already in the index, return it.
-                archive.metadata.requires_dist.clone()
+                archive.metadata.clone()
             } else {
                 // Run the PEP 517 build process to extract metadata from the source distribution.
                 let archive = self
@@ -206,17 +184,46 @@ impl<'a, Context: BuildContext> LookaheadResolver<'a, Context> {
                         }
                     })?;
 
-                let requires_dist = archive.metadata.requires_dist.clone();
+                let metadata = archive.metadata.clone();
 
                 // Insert the metadata into the index.
                 self.index
                     .distributions()
                     .done(id, Arc::new(MetadataResponse::Found(archive)));
 
-                requires_dist
+                metadata
             }
         };
 
+        // Respect recursive extras by propagating the source extras to the dependencies.
+        let requires_dist = metadata
+            .requires_dist
+            .into_iter()
+            .chain(
+                metadata
+                    .dev_dependencies
+                    .into_iter()
+                    .filter_map(|(group, dependencies)| {
+                        if self.dev.contains(&group) {
+                            Some(dependencies)
+                        } else {
+                            None
+                        }
+                    })
+                    .flatten(),
+            )
+            .map(|dependency| {
+                if dependency.name == requirement.name {
+                    Requirement {
+                        source: requirement.source.clone(),
+                        ..dependency
+                    }
+                } else {
+                    dependency
+                }
+            })
+            .collect();
+
         // Consider the dependencies to be "direct" if the requirement is a local source tree.
         let direct = if let Dist::Source(source_dist) = &dist {
             source_dist.as_path().is_some_and(std::path::Path::is_dir)
@@ -232,3 +239,60 @@ impl<'a, Context: BuildContext> LookaheadResolver<'a, Context> {
         )))
     }
 }
+
+/// Convert a [`Requirement`] into a [`Dist`], if it is a direct URL.
+fn required_dist(requirement: &Requirement) -> Result<Option<Dist>, distribution_types::Error> {
+    Ok(Some(match &requirement.source {
+        RequirementSource::Registry { .. } => return Ok(None),
+        RequirementSource::Url {
+            subdirectory,
+            location,
+            url,
+        } => Dist::from_http_url(
+            requirement.name.clone(),
+            url.clone(),
+            location.clone(),
+            subdirectory.clone(),
+        )?,
+        RequirementSource::Git {
+            repository,
+            reference,
+            precise,
+            subdirectory,
+            url,
+        } => {
+            let mut git_url = GitUrl::new(repository.clone(), reference.clone());
+            if let Some(precise) = precise {
+                git_url = git_url.with_precise(*precise);
+            }
+            Dist::Source(SourceDist::Git(GitSourceDist {
+                name: requirement.name.clone(),
+                git: Box::new(git_url),
+                subdirectory: subdirectory.clone(),
+                url: url.clone(),
+            }))
+        }
+        RequirementSource::Path {
+            install_path,
+            lock_path,
+            url,
+        } => Dist::from_file_url(
+            requirement.name.clone(),
+            url.clone(),
+            install_path,
+            lock_path,
+        )?,
+        RequirementSource::Directory {
+            install_path,
+            lock_path,
+            url,
+            editable,
+        } => Dist::from_directory_url(
+            requirement.name.clone(),
+            url.clone(),
+            install_path,
+            lock_path,
+            *editable,
+        )?,
+    }))
+}
