@@ -3,7 +3,7 @@ pub(crate) use crate::pubgrub::distribution::PubGrubDistribution;
 pub(crate) use crate::pubgrub::package::{PubGrubPackage, PubGrubPackageInner, PubGrubPython};
 pub(crate) use crate::pubgrub::priority::{PubGrubPriorities, PubGrubPriority};
 pub(crate) use crate::pubgrub::report::PubGrubReportFormatter;
-pub(crate) use crate::pubgrub::specifier::PubGrubSpecifier;
+pub use crate::pubgrub::specifier::{PubGrubSpecifier, PubGrubSpecifierError};
 
 mod dependencies;
 mod distribution;
