@@ -2,16 +2,18 @@
 use thiserror::Error;
 
 pub use crate::discovery::{
-    Error as DiscoveryError, SystemPython, ToolchainNotFound, ToolchainRequest, ToolchainSource,
-    ToolchainSources, VersionRequest,
+    find_toolchains, Error as DiscoveryError, SystemPython, ToolchainNotFound, ToolchainRequest,
+    ToolchainSource, ToolchainSources, VersionRequest,
 };
 pub use crate::environment::PythonEnvironment;
-pub use crate::interpreter::Interpreter;
+pub use crate::implementation::ImplementationName;
+pub use crate::interpreter::{Error as InterpreterError, Interpreter};
 pub use crate::pointer_size::PointerSize;
 pub use crate::prefix::Prefix;
 pub use crate::python_version::PythonVersion;
 pub use crate::target::Target;
 pub use crate::toolchain::Toolchain;
+pub use crate::version_files::{request_from_version_file, requests_from_version_file};
 pub use crate::virtualenv::{Error as VirtualEnvError, PyVenvConfiguration, VirtualEnvironment};
 
 mod discovery;
@@ -27,6 +29,7 @@ mod py_launcher;
 mod python_version;
 mod target;
 mod toolchain;
+mod version_files;
 mod virtualenv;
 
 #[cfg(not(test))]
@@ -62,6 +65,10 @@ pub enum Error {
     #[error(transparent)]
     Download(#[from] downloads::Error),
 
+    // TODO(zanieb) We might want to ensure this is always wrapped in another type
+    #[error(transparent)]
+    KeyError(#[from] toolchain::ToolchainKeyError),
+
     #[error(transparent)]
     NotFound(#[from] ToolchainNotFound),
 }
@@ -243,7 +250,7 @@ mod tests {
                 )
                 .replace("{FULL_VERSION}", &version.to_string())
                 .replace("{VERSION}", &version.without_patch().to_string())
-                .replace("{IMPLEMENTATION}", implementation.as_str());
+                .replace("{IMPLEMENTATION}", (&implementation).into());
 
             fs_err::create_dir_all(path.parent().unwrap())?;
             fs_err::write(
@@ -282,9 +289,9 @@ mod tests {
         }
 
         /// Create child directories in a temporary directory.
-        fn new_search_path_directories<P: AsRef<Path>>(
+        fn new_search_path_directories(
             &mut self,
-            names: &[P],
+            names: &[impl AsRef<Path>],
         ) -> Result<Vec<ChildPath>> {
             let paths = names
                 .iter()
@@ -1204,7 +1211,7 @@ mod tests {
         let toolchain =
             context.run_with_vars(&[("VIRTUAL_ENV", Some(venv.as_os_str()))], || {
                 Toolchain::find(
-                    Some("3.12"),
+                    Some(ToolchainRequest::parse("3.12")),
                     SystemPython::Required,
                     PreviewMode::Disabled,
                     &context.cache,
@@ -1219,7 +1226,7 @@ mod tests {
         // With a patch version that cannot be toolchain
         let result = context.run_with_vars(&[("VIRTUAL_ENV", Some(venv.as_os_str()))], || {
             Toolchain::find(
-                Some("3.12.3"),
+                Some(ToolchainRequest::parse("3.12.3")),
                 SystemPython::Required,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1262,7 +1269,7 @@ mod tests {
             &[("VIRTUAL_ENV", Some(context.tempdir.as_os_str()))],
             || {
                 Toolchain::find(
-                    Some("3.12.3"),
+                    Some(ToolchainRequest::parse("3.12.3")),
                     SystemPython::Required,
                     PreviewMode::Disabled,
                     &context.cache,
@@ -1289,7 +1296,7 @@ mod tests {
 
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some("foobar"),
+                Some(ToolchainRequest::parse("foobar")),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1316,7 +1323,7 @@ mod tests {
 
         let result = context.run(|| {
             Toolchain::find(
-                Some("3.10.0"),
+                Some(ToolchainRequest::parse("3.10.0")),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1343,7 +1350,7 @@ mod tests {
 
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some("./foo/bar"),
+                Some(ToolchainRequest::parse("./foo/bar")),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1358,7 +1365,7 @@ mod tests {
         context.add_python_versions(&["3.11.1"])?;
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some("./foo/bar"),
+                Some(ToolchainRequest::parse("./foo/bar")),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1386,7 +1393,7 @@ mod tests {
 
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some(python.to_str().unwrap()),
+                Some(ToolchainRequest::parse(python.to_str().unwrap())),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1401,7 +1408,7 @@ mod tests {
         // With `SystemPython::Explicit
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some(python.to_str().unwrap()),
+                Some(ToolchainRequest::parse(python.to_str().unwrap())),
                 SystemPython::Explicit,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1415,7 +1422,7 @@ mod tests {
 
         let result = context.run(|| {
             Toolchain::find(
-                Some(python.to_str().unwrap()),
+                Some(ToolchainRequest::parse(python.to_str().unwrap())),
                 SystemPython::Disallowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1435,7 +1442,7 @@ mod tests {
         context.add_python_versions(&["3.11.1"])?;
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some(python.to_str().unwrap()),
+                Some(ToolchainRequest::parse(python.to_str().unwrap())),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1458,7 +1465,7 @@ mod tests {
         TestContext::mock_venv(&venv, "3.10.0")?;
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some("../foo/.venv"),
+                Some(ToolchainRequest::parse("../foo/.venv")),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1472,7 +1479,7 @@ mod tests {
 
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some(venv.to_str().unwrap()),
+                Some(ToolchainRequest::parse(venv.to_str().unwrap())),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1494,7 +1501,9 @@ mod tests {
         )?;
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some(context.tempdir.child("bar").to_str().unwrap()),
+                Some(ToolchainRequest::parse(
+                    context.tempdir.child("bar").to_str().unwrap(),
+                )),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1512,7 +1521,7 @@ mod tests {
         let toolchain =
             context.run_with_vars(&[("VIRTUAL_ENV", Some(other_venv.as_os_str()))], || {
                 Toolchain::find(
-                    Some(venv.to_str().unwrap()),
+                    Some(ToolchainRequest::parse(venv.to_str().unwrap())),
                     SystemPython::Allowed,
                     PreviewMode::Disabled,
                     &context.cache,
@@ -1534,7 +1543,7 @@ mod tests {
 
         let result = context.run(|| {
             Toolchain::find(
-                Some("./foo/bar"),
+                Some(ToolchainRequest::parse("./foo/bar")),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1566,7 +1575,7 @@ mod tests {
         let toolchain = context
             .run(|| {
                 Toolchain::find(
-                    Some("bar"),
+                    Some(ToolchainRequest::parse("bar")),
                     SystemPython::Allowed,
                     PreviewMode::Disabled,
                     &context.cache,
@@ -1622,7 +1631,7 @@ mod tests {
         let toolchain = context
             .run(|| {
                 Toolchain::find(
-                    Some("pypy"),
+                    Some(ToolchainRequest::parse("pypy")),
                     SystemPython::Allowed,
                     PreviewMode::Disabled,
                     &context.cache,
@@ -1649,7 +1658,7 @@ mod tests {
         let toolchain = context
             .run(|| {
                 Toolchain::find(
-                    Some("pypy"),
+                    Some(ToolchainRequest::parse("pypy")),
                     SystemPython::Allowed,
                     PreviewMode::Disabled,
                     &context.cache,
@@ -1691,7 +1700,7 @@ mod tests {
 
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some("pypy3.10"),
+                Some(ToolchainRequest::parse("pypy3.10")),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1717,7 +1726,7 @@ mod tests {
 
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some("pypy@3.10"),
+                Some(ToolchainRequest::parse("pypy@3.10")),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1754,7 +1763,7 @@ mod tests {
 
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some("pypy@3.10"),
+                Some(ToolchainRequest::parse("pypy@3.10")),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1773,7 +1782,7 @@ mod tests {
         ])?;
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some("pypy@3.10"),
+                Some(ToolchainRequest::parse("pypy@3.10")),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1806,7 +1815,7 @@ mod tests {
 
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some("pypy@3.10"),
+                Some(ToolchainRequest::parse("pypy@3.10")),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
@@ -1835,7 +1844,7 @@ mod tests {
 
         let toolchain = context.run(|| {
             Toolchain::find(
-                Some("pypy@3.10"),
+                Some(ToolchainRequest::parse("pypy@3.10")),
                 SystemPython::Allowed,
                 PreviewMode::Disabled,
                 &context.cache,
