@@ -1,4 +1,3 @@
-use std::borrow::Cow;
 use std::fmt::Write;
 
 use anstream::eprint;
@@ -8,29 +7,30 @@ use tracing::debug;
 
 use distribution_types::{IndexLocations, Resolution};
 use install_wheel_rs::linker::LinkMode;
-use platform_tags::Tags;
 use uv_auth::store_credentials_from_url;
 use uv_cache::Cache;
 use uv_client::{BaseClientBuilder, Connectivity, FlatIndexClient, RegistryClientBuilder};
 use uv_configuration::{
-    Concurrency, ConfigSettings, ExtrasSpecification, IndexStrategy, NoBinary, NoBuild,
-    PreviewMode, Reinstall, SetupPyStrategy, Upgrade,
+    BuildOptions, Concurrency, ConfigSettings, ExtrasSpecification, IndexStrategy, PreviewMode,
+    Reinstall, SetupPyStrategy, Upgrade,
 };
 use uv_configuration::{KeyringProviderType, TargetTriple};
 use uv_dispatch::BuildDispatch;
 use uv_fs::Simplified;
 use uv_git::GitResolver;
 use uv_installer::SitePackages;
-use uv_interpreter::{PythonEnvironment, PythonVersion, SystemPython, Target};
 use uv_requirements::{RequirementsSource, RequirementsSpecification};
 use uv_resolver::{
     DependencyMode, ExcludeNewer, FlatIndex, InMemoryIndex, OptionsBuilder, PreReleaseMode,
     ResolutionMode,
 };
+use uv_toolchain::{
+    Prefix, PythonEnvironment, PythonVersion, SystemPython, Target, Toolchain, ToolchainRequest,
+};
 use uv_types::{BuildIsolation, HashStrategy, InFlight};
 
-use crate::commands::pip::operations;
 use crate::commands::pip::operations::Modifications;
+use crate::commands::pip::{operations, resolution_environment};
 use crate::commands::ExitStatus;
 use crate::printer::Printer;
 
@@ -39,7 +39,7 @@ use crate::printer::Printer;
 pub(crate) async fn pip_sync(
     requirements: &[RequirementsSource],
     constraints: &[RequirementsSource],
-    reinstall: &Reinstall,
+    reinstall: Reinstall,
     link_mode: LinkMode,
     compile: bool,
     require_hashes: bool,
@@ -50,8 +50,7 @@ pub(crate) async fn pip_sync(
     connectivity: Connectivity,
     config_settings: &ConfigSettings,
     no_build_isolation: bool,
-    no_build: NoBuild,
-    no_binary: NoBinary,
+    build_options: BuildOptions,
     python_version: Option<PythonVersion>,
     python_platform: Option<TargetTriple>,
     strict: bool,
@@ -60,6 +59,7 @@ pub(crate) async fn pip_sync(
     system: bool,
     break_system_packages: bool,
     target: Option<Target>,
+    prefix: Option<Prefix>,
     concurrency: Concurrency,
     native_tls: bool,
     preview: PreviewMode,
@@ -91,8 +91,8 @@ pub(crate) async fn pip_sync(
         extra_index_urls,
         no_index,
         find_links,
-        no_binary: specified_no_binary,
-        no_build: specified_no_build,
+        no_binary,
+        no_build,
         extras: _,
     } = operations::read_requirements(
         requirements,
@@ -116,85 +116,64 @@ pub(crate) async fn pip_sync(
     } else {
         SystemPython::Explicit
     };
-    let venv = PythonEnvironment::find(python.as_deref(), system, preview, &cache)?;
+    let environment = PythonEnvironment::from_toolchain(Toolchain::find(
+        python.as_deref().map(ToolchainRequest::parse),
+        system,
+        preview,
+        &cache,
+    )?);
 
     debug!(
         "Using Python {} environment at {}",
-        venv.interpreter().python_version(),
-        venv.python_executable().user_display().cyan()
+        environment.interpreter().python_version(),
+        environment.python_executable().user_display().cyan()
     );
 
-    // Apply any `--target` directory.
-    let venv = if let Some(target) = target {
+    // Apply any `--target` or `--prefix` directories.
+    let environment = if let Some(target) = target {
         debug!(
             "Using `--target` directory at {}",
             target.root().user_display()
         );
         target.init()?;
-        venv.with_target(target)
+        environment.with_target(target)
+    } else if let Some(prefix) = prefix {
+        debug!(
+            "Using `--prefix` directory at {}",
+            prefix.root().user_display()
+        );
+        prefix.init()?;
+        environment.with_prefix(prefix)
     } else {
-        venv
+        environment
     };
 
     // If the environment is externally managed, abort.
-    if let Some(externally_managed) = venv.interpreter().is_externally_managed() {
+    if let Some(externally_managed) = environment.interpreter().is_externally_managed() {
         if break_system_packages {
             debug!("Ignoring externally managed environment due to `--break-system-packages`");
         } else {
             return if let Some(error) = externally_managed.into_error() {
                 Err(anyhow::anyhow!(
                     "The interpreter at {} is externally managed, and indicates the following:\n\n{}\n\nConsider creating a virtual environment with `uv venv`.",
-                    venv.root().user_display().cyan(),
+                    environment.root().user_display().cyan(),
                     textwrap::indent(&error, "  ").green(),
                 ))
             } else {
                 Err(anyhow::anyhow!(
                     "The interpreter at {} is externally managed. Instead, create a virtual environment with `uv venv`.",
-                    venv.root().user_display().cyan()
+                    environment.root().user_display().cyan()
                 ))
             };
         }
     }
 
-    let _lock = venv.lock()?;
+    let _lock = environment.lock()?;
 
-    let interpreter = venv.interpreter();
+    let interpreter = environment.interpreter();
 
-    // Determine the current environment markers.
-    let tags = match (python_platform, python_version.as_ref()) {
-        (Some(python_platform), Some(python_version)) => Cow::Owned(Tags::from_env(
-            &python_platform.platform(),
-            (python_version.major(), python_version.minor()),
-            interpreter.implementation_name(),
-            interpreter.implementation_tuple(),
-            interpreter.gil_disabled(),
-        )?),
-        (Some(python_platform), None) => Cow::Owned(Tags::from_env(
-            &python_platform.platform(),
-            interpreter.python_tuple(),
-            interpreter.implementation_name(),
-            interpreter.implementation_tuple(),
-            interpreter.gil_disabled(),
-        )?),
-        (None, Some(python_version)) => Cow::Owned(Tags::from_env(
-            interpreter.platform(),
-            (python_version.major(), python_version.minor()),
-            interpreter.implementation_name(),
-            interpreter.implementation_tuple(),
-            interpreter.gil_disabled(),
-        )?),
-        (None, None) => Cow::Borrowed(interpreter.tags()?),
-    };
-
-    // Apply the platform tags to the markers.
-    let markers = match (python_platform, python_version) {
-        (Some(python_platform), Some(python_version)) => {
-            Cow::Owned(python_version.markers(&python_platform.markers(interpreter.markers())))
-        }
-        (Some(python_platform), None) => Cow::Owned(python_platform.markers(interpreter.markers())),
-        (None, Some(python_version)) => Cow::Owned(python_version.markers(interpreter.markers())),
-        (None, None) => Cow::Borrowed(interpreter.markers()),
-    };
+    // Determine the environment for the resolution.
+    let (tags, markers) = resolution_environment(python_version, python_platform, interpreter)?;
 
     // Collect the set of required hashes.
     let hasher = if require_hashes {
@@ -228,24 +207,23 @@ pub(crate) async fn pip_sync(
         .platform(interpreter.platform())
         .build();
 
+    // Combine the `--no-binary` and `--no-build` flags from the requirements files.
+    let build_options = build_options.combine(no_binary, no_build);
+
     // Resolve the flat indexes from `--find-links`.
     let flat_index = {
         let client = FlatIndexClient::new(&client, &cache);
         let entries = client.fetch(index_locations.flat_index()).await?;
-        FlatIndex::from_entries(entries, &tags, &hasher, &no_build, &no_binary)
+        FlatIndex::from_entries(entries, Some(&tags), &hasher, &build_options)
     };
 
     // Determine whether to enable build isolation.
     let build_isolation = if no_build_isolation {
-        BuildIsolation::Shared(&venv)
+        BuildIsolation::Shared(&environment)
     } else {
         BuildIsolation::Isolated
     };
 
-    // Combine the `--no-binary` and `--no-build` flags.
-    let no_binary = no_binary.combine(specified_no_binary);
-    let no_build = no_build.combine(specified_no_build);
-
     // Create a shared in-memory index.
     let index = InMemoryIndex::default();
 
@@ -256,6 +234,9 @@ pub(crate) async fn pip_sync(
     let preferences = Vec::default();
     let git = GitResolver::default();
 
+    // Ignore development dependencies.
+    let dev = Vec::default();
+
     // Create a build dispatch for resolution.
     let resolve_dispatch = BuildDispatch::new(
         &client,
@@ -270,15 +251,14 @@ pub(crate) async fn pip_sync(
         config_settings,
         build_isolation,
         link_mode,
-        &no_build,
-        &no_binary,
+        &build_options,
         concurrency,
         preview,
     )
     .with_options(OptionsBuilder::new().exclude_newer(exclude_newer).build());
 
     // Determine the set of installed packages.
-    let site_packages = SitePackages::from_executable(&venv)?;
+    let site_packages = SitePackages::from_executable(&environment)?;
 
     let options = OptionsBuilder::new()
         .resolution_mode(resolution_mode)
@@ -292,16 +272,17 @@ pub(crate) async fn pip_sync(
         requirements,
         constraints,
         overrides,
+        dev,
         source_trees,
         project,
         &extras,
         preferences,
         site_packages.clone(),
         &hasher,
-        reinstall,
+        &reinstall,
         &upgrade,
         interpreter,
-        &tags,
+        Some(&tags),
         Some(&markers),
         None,
         &client,
@@ -346,8 +327,7 @@ pub(crate) async fn pip_sync(
             config_settings,
             build_isolation,
             link_mode,
-            &no_build,
-            &no_binary,
+            &build_options,
             concurrency,
             preview,
         )
@@ -359,8 +339,8 @@ pub(crate) async fn pip_sync(
         &resolution,
         site_packages,
         Modifications::Exact,
-        reinstall,
-        &no_binary,
+        &reinstall,
+        &build_options,
         link_mode,
         compile,
         &index_locations,
@@ -371,7 +351,7 @@ pub(crate) async fn pip_sync(
         concurrency,
         &install_dispatch,
         &cache,
-        &venv,
+        &environment,
         dry_run,
         printer,
         preview,
@@ -383,7 +363,7 @@ pub(crate) async fn pip_sync(
 
     // Notify the user of any environment diagnostics.
     if strict && !dry_run {
-        operations::diagnose_environment(&resolution, &venv, printer)?;
+        operations::diagnose_environment(&resolution, &environment, printer)?;
     }
 
     Ok(ExitStatus::Success)
