@@ -6,6 +6,7 @@ use uv_client::Connectivity;
 use uv_configuration::{Concurrency, ExtrasSpecification, PreviewMode};
 use uv_distribution::pyproject_mut::PyProjectTomlMut;
 use uv_distribution::ProjectWorkspace;
+use uv_toolchain::ToolchainRequest;
 use uv_warnings::warn_user;
 
 use crate::commands::pip::operations::Modifications;
@@ -45,7 +46,7 @@ pub(crate) async fn remove(
                     .filter(|deps| !deps.is_empty())
                     .is_some()
                 {
-                    uv_warnings::warn_user!("`{req}` is not a development dependency; try calling `uv add` without the `--dev` flag");
+                    uv_warnings::warn_user!("`{req}` is not a development dependency; try calling `uv remove` without the `--dev` flag");
                 }
 
                 anyhow::bail!("The dependency `{req}` could not be found in `dev-dependencies`");
@@ -64,7 +65,7 @@ pub(crate) async fn remove(
                 .is_some()
             {
                 uv_warnings::warn_user!(
-                    "`{req}` is a development dependency; try calling `uv add --dev`"
+                    "`{req}` is a development dependency; try calling `uv remove --dev`"
                 );
             }
 
@@ -81,7 +82,15 @@ pub(crate) async fn remove(
     )?;
 
     // Discover or create the virtual environment.
-    let venv = project::init_environment(project.workspace(), python.as_deref(), cache, printer)?;
+    let venv = project::init_environment(
+        project.workspace(),
+        python.as_deref().map(ToolchainRequest::parse),
+        connectivity,
+        native_tls,
+        cache,
+        printer,
+    )
+    .await?;
 
     // Use the default settings.
     let settings = ResolverSettings::default();
