@@ -2,41 +2,40 @@ use std::ffi::OsString;
 use std::path::PathBuf;
 
 use anyhow::{Context, Result};
-use distribution_types::IndexLocations;
 use itertools::Itertools;
-use tempfile::tempdir_in;
 use tokio::process::Command;
 use tracing::debug;
 
 use uv_cache::Cache;
-use uv_client::Connectivity;
-use uv_configuration::{ExtrasSpecification, PreviewMode, Upgrade};
+use uv_client::{BaseClientBuilder, Connectivity};
+use uv_configuration::{Concurrency, ExtrasSpecification, PreviewMode};
 use uv_distribution::{ProjectWorkspace, Workspace};
-use uv_interpreter::{PythonEnvironment, SystemPython};
 use uv_normalize::PackageName;
 use uv_requirements::RequirementsSource;
-use uv_resolver::ExcludeNewer;
+use uv_toolchain::{PythonEnvironment, SystemPython, Toolchain, ToolchainRequest};
 use uv_warnings::warn_user;
 
+use crate::commands::pip::operations::Modifications;
 use crate::commands::{project, ExitStatus};
 use crate::printer::Printer;
+use crate::settings::ResolverInstallerSettings;
 
 /// Run a command.
 #[allow(clippy::too_many_arguments)]
 pub(crate) async fn run(
-    index_locations: IndexLocations,
     extras: ExtrasSpecification,
     dev: bool,
     target: Option<String>,
     mut args: Vec<OsString>,
     requirements: Vec<RequirementsSource>,
     python: Option<String>,
-    upgrade: Upgrade,
-    exclude_newer: Option<ExcludeNewer>,
     package: Option<PackageName>,
+    settings: ResolverInstallerSettings,
     isolated: bool,
     preview: PreviewMode,
     connectivity: Connectivity,
+    concurrency: Concurrency,
+    native_tls: bool,
     cache: &Cache,
     printer: Printer,
 ) -> Result<ExitStatus> {
@@ -61,28 +60,58 @@ pub(crate) async fn run(
         } else {
             ProjectWorkspace::discover(&std::env::current_dir()?, None).await?
         };
-        let venv = project::init_environment(&project, preview, cache, printer)?;
+        let venv = project::init_environment(
+            project.workspace(),
+            python.as_deref().map(ToolchainRequest::parse),
+            connectivity,
+            native_tls,
+            cache,
+            printer,
+        )
+        .await?;
 
         // Lock and sync the environment.
         let lock = project::lock::do_lock(
-            &project,
-            &venv,
-            &index_locations,
-            upgrade,
-            exclude_newer,
+            project.workspace(),
+            venv.interpreter(),
+            &settings.upgrade,
+            &settings.index_locations,
+            &settings.index_strategy,
+            &settings.keyring_provider,
+            &settings.resolution,
+            &settings.prerelease,
+            &settings.config_setting,
+            settings.exclude_newer.as_ref(),
+            &settings.link_mode,
+            &settings.build_options,
             preview,
+            connectivity,
+            concurrency,
+            native_tls,
             cache,
             printer,
         )
         .await?;
         project::sync::do_sync(
-            &project,
+            project.project_name(),
+            project.workspace().root(),
             &venv,
             &lock,
-            &index_locations,
             extras,
             dev,
+            Modifications::Sufficient,
+            &settings.reinstall,
+            &settings.index_locations,
+            &settings.index_strategy,
+            &settings.keyring_provider,
+            &settings.config_setting,
+            &settings.link_mode,
+            &settings.compile_bytecode,
+            &settings.build_options,
             preview,
+            connectivity,
+            concurrency,
+            native_tls,
             cache,
             printer,
         )
@@ -92,20 +121,30 @@ pub(crate) async fn run(
     };
 
     // If necessary, create an environment for the ephemeral requirements.
-    let tmpdir;
+    let temp_dir;
     let ephemeral_env = if requirements.is_empty() {
         None
     } else {
         debug!("Syncing ephemeral environment.");
 
+        let client_builder = BaseClientBuilder::new()
+            .connectivity(connectivity)
+            .native_tls(native_tls);
+
         // Discover an interpreter.
         let interpreter = if let Some(project_env) = &project_env {
             project_env.interpreter().clone()
-        } else if let Some(python) = python.as_ref() {
-            PythonEnvironment::from_requested_python(python, SystemPython::Allowed, preview, cache)?
-                .into_interpreter()
         } else {
-            PythonEnvironment::from_default_python(preview, cache)?.into_interpreter()
+            // Note we force preview on during `uv run` for now since the entire interface is in preview
+            Toolchain::find_or_fetch(
+                python.as_deref().map(ToolchainRequest::parse),
+                SystemPython::Allowed,
+                PreviewMode::Enabled,
+                client_builder,
+                cache,
+            )
+            .await?
+            .into_interpreter()
         };
 
         // TODO(charlie): If the environment satisfies the requirements, skip creation.
@@ -114,12 +153,9 @@ pub(crate) async fn run(
         // environment.
 
         // Create a virtual environment
-        // TODO(zanieb): Move this path derivation elsewhere
-        let uv_state_path = std::env::current_dir()?.join(".uv");
-        fs_err::create_dir_all(&uv_state_path)?;
-        tmpdir = tempdir_in(uv_state_path)?;
+        temp_dir = cache.environment()?;
         let venv = uv_virtualenv::create_venv(
-            tmpdir.path(),
+            temp_dir.path(),
             interpreter,
             uv_virtualenv::Prompt::None,
             false,
@@ -131,11 +167,13 @@ pub(crate) async fn run(
             project::update_environment(
                 venv,
                 &requirements,
-                &index_locations,
+                &settings,
+                preview,
                 connectivity,
+                concurrency,
+                native_tls,
                 cache,
                 printer,
-                preview,
             )
             .await?,
         )
