@@ -1,13 +1,14 @@
-use anyhow::Result;
 use std::path::Path;
 
+use anyhow::Result;
+
 use distribution_types::IndexLocations;
 use install_wheel_rs::linker::LinkMode;
 use uv_cache::Cache;
-use uv_client::{FlatIndexClient, RegistryClientBuilder};
+use uv_client::{Connectivity, FlatIndexClient, RegistryClientBuilder};
 use uv_configuration::{
-    Concurrency, ConfigSettings, ExtrasSpecification, NoBinary, NoBuild, PreviewMode, Reinstall,
-    SetupPyStrategy,
+    BuildOptions, Concurrency, ConfigSettings, ExtrasSpecification, IndexStrategy,
+    KeyringProviderType, PreviewMode, Reinstall, SetupPyStrategy,
 };
 use uv_dispatch::BuildDispatch;
 use uv_distribution::{ProjectWorkspace, DEV_DEPENDENCIES};
@@ -15,7 +16,7 @@ use uv_git::GitResolver;
 use uv_installer::SitePackages;
 use uv_normalize::PackageName;
 use uv_resolver::{FlatIndex, InMemoryIndex, Lock};
-use uv_toolchain::PythonEnvironment;
+use uv_toolchain::{PythonEnvironment, ToolchainRequest};
 use uv_types::{BuildIsolation, HashStrategy, InFlight};
 use uv_warnings::warn_user;
 
@@ -23,15 +24,20 @@ use crate::commands::pip::operations::Modifications;
 use crate::commands::project::ProjectError;
 use crate::commands::{pip, project, ExitStatus};
 use crate::printer::Printer;
+use crate::settings::InstallerSettings;
 
 /// Sync the project environment.
 #[allow(clippy::too_many_arguments)]
 pub(crate) async fn sync(
-    index_locations: IndexLocations,
     extras: ExtrasSpecification,
     dev: bool,
+    modifications: Modifications,
     python: Option<String>,
+    settings: InstallerSettings,
     preview: PreviewMode,
+    connectivity: Connectivity,
+    concurrency: Concurrency,
+    native_tls: bool,
     cache: &Cache,
     printer: Printer,
 ) -> Result<ExitStatus> {
@@ -45,11 +51,13 @@ pub(crate) async fn sync(
     // Discover or create the virtual environment.
     let venv = project::init_environment(
         project.workspace(),
-        python.as_deref(),
-        preview,
+        python.as_deref().map(ToolchainRequest::parse),
+        connectivity,
+        native_tls,
         cache,
         printer,
-    )?;
+    )
+    .await?;
 
     // Read the lockfile.
     let lock: Lock = {
@@ -64,10 +72,21 @@ pub(crate) async fn sync(
         project.workspace().root(),
         &venv,
         &lock,
-        &index_locations,
         extras,
         dev,
+        modifications,
+        &settings.reinstall,
+        &settings.index_locations,
+        &settings.index_strategy,
+        &settings.keyring_provider,
+        &settings.config_setting,
+        &settings.link_mode,
+        &settings.compile_bytecode,
+        &settings.build_options,
         preview,
+        connectivity,
+        concurrency,
+        native_tls,
         cache,
         printer,
     )
@@ -83,10 +102,21 @@ pub(super) async fn do_sync(
     workspace_root: &Path,
     venv: &PythonEnvironment,
     lock: &Lock,
-    index_locations: &IndexLocations,
     extras: ExtrasSpecification,
     dev: bool,
+    modifications: Modifications,
+    reinstall: &Reinstall,
+    index_locations: &IndexLocations,
+    index_strategy: &IndexStrategy,
+    keyring_provider: &KeyringProviderType,
+    config_setting: &ConfigSettings,
+    link_mode: &LinkMode,
+    compile_bytecode: &bool,
+    build_options: &BuildOptions,
     preview: PreviewMode,
+    connectivity: Connectivity,
+    concurrency: Concurrency,
+    native_tls: bool,
     cache: &Cache,
     printer: Printer,
 ) -> Result<(), ProjectError> {
@@ -115,34 +145,33 @@ pub(super) async fn do_sync(
         lock.to_resolution(workspace_root, markers, tags, project_name, &extras, &dev)?;
 
     // Initialize the registry client.
-    // TODO(zanieb): Support client options e.g. offline, tls, etc.
     let client = RegistryClientBuilder::new(cache.clone())
+        .native_tls(native_tls)
+        .connectivity(connectivity)
         .index_urls(index_locations.index_urls())
+        .index_strategy(*index_strategy)
+        .keyring(*keyring_provider)
         .markers(markers)
         .platform(venv.interpreter().platform())
         .build();
 
-    // TODO(charlie): Respect project configuration.
-    let build_isolation = BuildIsolation::default();
-    let compile = false;
-    let concurrency = Concurrency::default();
-    let config_settings = ConfigSettings::default();
-    let dry_run = false;
+    // Initialize any shared state.
     let git = GitResolver::default();
-    let hasher = HashStrategy::default();
     let in_flight = InFlight::default();
     let index = InMemoryIndex::default();
-    let link_mode = LinkMode::default();
-    let no_binary = NoBinary::default();
-    let no_build = NoBuild::default();
-    let reinstall = Reinstall::default();
+
+    // TODO(charlie): These are all default values. We should consider whether we want to make them
+    // optional on the downstream APIs.
+    let build_isolation = BuildIsolation::default();
+    let dry_run = false;
+    let hasher = HashStrategy::default();
     let setup_py = SetupPyStrategy::default();
 
     // Resolve the flat indexes from `--find-links`.
     let flat_index = {
         let client = FlatIndexClient::new(&client, cache);
         let entries = client.fetch(index_locations.flat_index()).await?;
-        FlatIndex::from_entries(entries, Some(tags), &hasher, &no_build, &no_binary)
+        FlatIndex::from_entries(entries, Some(tags), &hasher, build_options)
     };
 
     // Create a build dispatch.
@@ -156,11 +185,10 @@ pub(super) async fn do_sync(
         &git,
         &in_flight,
         setup_py,
-        &config_settings,
+        config_setting,
         build_isolation,
-        link_mode,
-        &no_build,
-        &no_binary,
+        *link_mode,
+        build_options,
         concurrency,
         preview,
     );
@@ -171,11 +199,11 @@ pub(super) async fn do_sync(
     pip::operations::install(
         &resolution,
         site_packages,
-        Modifications::Sufficient,
-        &reinstall,
-        &no_binary,
-        link_mode,
-        compile,
+        modifications,
+        reinstall,
+        build_options,
+        *link_mode,
+        *compile_bytecode,
         index_locations,
         &hasher,
         tags,
