@@ -1,22 +1,22 @@
 use std::ffi::OsString;
 use std::path::PathBuf;
 
-use anyhow::Result;
+use anyhow::{Context, Result};
 use itertools::Itertools;
-use tempfile::tempdir_in;
 use tokio::process::Command;
 use tracing::debug;
 
 use uv_cache::Cache;
 use uv_client::Connectivity;
-use uv_configuration::PreviewMode;
-use uv_interpreter::{PythonEnvironment, SystemPython};
+use uv_configuration::{Concurrency, PreviewMode};
 use uv_requirements::RequirementsSource;
+use uv_toolchain::{PythonEnvironment, SystemPython, Toolchain, ToolchainRequest};
 use uv_warnings::warn_user;
 
 use crate::commands::project::update_environment;
 use crate::commands::ExitStatus;
 use crate::printer::Printer;
+use crate::settings::ResolverInstallerSettings;
 
 /// Run a command.
 #[allow(clippy::too_many_arguments)]
@@ -26,9 +26,12 @@ pub(crate) async fn run(
     python: Option<String>,
     from: Option<String>,
     with: Vec<String>,
+    settings: ResolverInstallerSettings,
     _isolated: bool,
     preview: PreviewMode,
     connectivity: Connectivity,
+    concurrency: Concurrency,
+    native_tls: bool,
     cache: &Cache,
     printer: Printer,
 ) -> Result<ExitStatus> {
@@ -43,27 +46,26 @@ pub(crate) async fn run(
     .chain(with.into_iter().map(RequirementsSource::from_package))
     .collect::<Vec<_>>();
 
-    // TODO(zanieb): When implementing project-level tools, discover the project and check if it has the tool
-    // TOOD(zanieb): Determine if we sould layer on top of the project environment if it is present
+    // TODO(zanieb): When implementing project-level tools, discover the project and check if it has the tool.
+    // TODO(zanieb): Determine if we should layer on top of the project environment if it is present.
 
     // If necessary, create an environment for the ephemeral requirements.
     debug!("Syncing ephemeral environment.");
 
     // Discover an interpreter.
-    let interpreter = if let Some(python) = python.as_ref() {
-        PythonEnvironment::from_requested_python(python, SystemPython::Allowed, cache)?
-            .into_interpreter()
-    } else {
-        PythonEnvironment::from_default_python(cache)?.into_interpreter()
-    };
+    // Note we force preview on during `uv tool run` for now since the entire interface is in preview
+    let interpreter = Toolchain::find(
+        python.as_deref().map(ToolchainRequest::parse),
+        SystemPython::Allowed,
+        PreviewMode::Enabled,
+        cache,
+    )?
+    .into_interpreter();
 
-    // Create a virtual environment
-    // TODO(zanieb): Move this path derivation elsewhere
-    let uv_state_path = std::env::current_dir()?.join(".uv");
-    fs_err::create_dir_all(&uv_state_path)?;
-    let tmpdir = tempdir_in(uv_state_path)?;
+    // Create a virtual environment.
+    let temp_dir = cache.environment()?;
     let venv = uv_virtualenv::create_venv(
-        tmpdir.path(),
+        temp_dir.path(),
         interpreter,
         uv_virtualenv::Prompt::None,
         false,
@@ -71,8 +73,20 @@ pub(crate) async fn run(
     )?;
 
     // Install the ephemeral requirements.
-    let ephemeral_env =
-        Some(update_environment(venv, &requirements, preview, connectivity, cache, printer).await?);
+    let ephemeral_env = Some(
+        update_environment(
+            venv,
+            &requirements,
+            &settings,
+            preview,
+            connectivity,
+            concurrency,
+            native_tls,
+            cache,
+            printer,
+        )
+        .await?,
+    );
 
     // TODO(zanieb): Determine the command via the package entry points
     let command = target;
@@ -122,8 +136,10 @@ pub(crate) async fn run(
         "Running `{command}{space}{}`",
         args.iter().map(|arg| arg.to_string_lossy()).join(" ")
     );
-    let mut handle = process.spawn()?;
-    let status = handle.wait().await?;
+    let mut handle = process
+        .spawn()
+        .with_context(|| format!("Failed to spawn: `{command}`"))?;
+    let status = handle.wait().await.context("Child process disappeared")?;
 
     // Exit based on the result of the command
     // TODO(zanieb): Do we want to exit with the code of the child process? Probably.
