@@ -23,7 +23,7 @@ use uv_dispatch::BuildDispatch;
 use uv_fs::Simplified;
 use uv_git::GitResolver;
 use uv_resolver::{ExcludeNewer, FlatIndex, InMemoryIndex, OptionsBuilder};
-use uv_toolchain::{SystemPython, Toolchain, ToolchainRequest};
+use uv_toolchain::{request_from_version_file, SystemPython, Toolchain, ToolchainRequest};
 use uv_types::{BuildContext, BuildIsolation, HashStrategy, InFlight};
 
 use crate::commands::{pip, ExitStatus};
@@ -125,9 +125,14 @@ async fn venv_impl(
         .connectivity(connectivity)
         .native_tls(native_tls);
 
+    let mut interpreter_request = python_request.map(ToolchainRequest::parse);
+    if preview.is_enabled() && interpreter_request.is_none() {
+        interpreter_request = request_from_version_file().await.into_diagnostic()?;
+    }
+
     // Locate the Python interpreter to use in the environment
     let interpreter = Toolchain::find_or_fetch(
-        python_request.map(ToolchainRequest::parse),
+        interpreter_request,
         SystemPython::Required,
         preview,
         client_builder,
